import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;

import com.tangosol.net.CacheFactory;
import com.tangosol.net.NamedCache;

public class CacheLoading {

	public static void loadPricesFor(String symbol, NamedCache namedCache) throws IOException, NumberFormatException, ParseException {

		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");

		String fileName = "./endofdaystocksummaries/" + symbol + ".csv";
		
		BufferedReader in = new BufferedReader(new FileReader(fileName));
		in.readLine();

		String line = null;
		while ((line = in.readLine()) != null) {
			String[] parts = line.split(",");
	
			EndOfDayStockSummary eodss = 
				new EndOfDayStockSummary(symbol,
						 				 dateFormat.parse(parts[0]).getTime(), 
						 				 Double.parseDouble(parts[1]),
						 				 Double.parseDouble(parts[2]),
						 				 Double.parseDouble(parts[3]),
						 				 Double.parseDouble(parts[4]),
						 				 Double.parseDouble(parts[6]),
						 				 Long.parseLong(parts[5]));
				
			namedCache.put(eodss.getKey(), eodss);
		}
		
		in.close();		
	}
	
	
	/**
	 * @param args
	 * @throws IOException 
	 * @throws ParseException 
	 * @throws NumberFormatException 
	 */
	public static void main(String[] args) throws IOException, NumberFormatException, ParseException {

		NamedCache namedCache = CacheFactory.getCache("eodss");
		
		String[] symbols = {"AAPL", "BT", "DELL", "GOOG", "HPQ", "JAVA", "MSFT", "ORCL", "YHOO"}; 
	
		for (String symbol : symbols) {
			loadPricesFor(symbol, namedCache);
		}	
	}

}
