import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Date;
import java.util.Map;
import java.util.Set;

import com.tangosol.net.CacheFactory;
import com.tangosol.net.NamedCache;
import com.tangosol.util.AbstractMapListener;
import com.tangosol.util.MapEvent;
import com.tangosol.util.UUID;
import com.tangosol.util.aggregator.Count;
import com.tangosol.util.filter.EqualsFilter;
import com.tangosol.util.filter.MapEventFilter;
import com.tangosol.util.filter.NotEqualsFilter;


public class Chat {

	@SuppressWarnings("unchecked")
	public static void main(String[] args) throws IOException {

		System.out.println("Welcome to Chat");
		System.out.println("---------------");
		
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
	
		System.out.print("Please enter your name >");
		String user = in.readLine();
		
		NamedCache messages = CacheFactory.getCache("messages");
		messages.addMapListener(new AbstractMapListener() {
			public void entryInserted(MapEvent evt) {
				Message message = (Message)evt.getNewValue();
				System.out.printf("Received Message from %s at %s\n%s\n", 
								  message.getFrom(),
								  new Date(message.getTimeCreated()),
								  message.getText());
			}
		}, new MapEventFilter(MapEventFilter.E_INSERTED, new NotEqualsFilter("getFrom", user)), false);

		String command;
		do {
			System.out.print(">");
			command = in.readLine();
			
			if (command.startsWith("numberfrom ")) {
				String from = command.substring(10).trim();
				
				int count = (Integer)messages.aggregate(new EqualsFilter("getFrom", from), new Count());
				
				System.out.printf("Number from %s is %d\n\n", from, count);
				
			} else if (command.startsWith("from ")) {
				String from = command.substring(5).trim();
				
				Set<Map.Entry<UUID, Message>> results = messages.entrySet(new EqualsFilter("getFrom", from), null);
				
				for(Map.Entry<UUID, Message> entry : results) {
					System.out.printf("Old message from %s at %s was\n%s\n\n",
									  entry.getValue().getFrom(),
									  entry.getValue().getDate(),
									  entry.getValue().getText());
				}
				
			} else {
				messages.put(new UUID(), new Message(user, command));
			}
			
		} while (!command.equals("bye"));
	}
}
