
import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Date;

import com.tangosol.io.ExternalizableLite;
import com.tangosol.util.ExternalizableHelper;


public class EndOfDayStockSummaryExternalizableLite implements ExternalizableLite {

	private static final long serialVersionUID = -200684451000777011L;

	private String symbol;
	private long date;
	private double openPrice;
	private double highPrice;
	private double lowPrice;
	private double closePrice;
	private double adjustedClosePrice;
	private long volume;
	
	
	public EndOfDayStockSummaryExternalizableLite() {
		//for serializable
	}


	public EndOfDayStockSummaryExternalizableLite(String symbol, 
						 						  long date, 
						 						  double openPrice,
						 						  double highPrice, 
						 						  double lowPrice, 
						 						  double closePrice,
						 						  double adjustedClosePrice, 
						 						  long volume) {
		this.symbol = symbol;
		this.date = date;
		this.openPrice = openPrice;
		this.highPrice = highPrice;
		this.lowPrice = lowPrice;
		this.closePrice = closePrice;
		this.adjustedClosePrice = adjustedClosePrice;
		this.volume = volume;
	}
		
	
	public String getKey() {
		return symbol + date;
	}
	
	
	public String getSymbol() {
		return symbol;
	}


	public long getDate() {
		return date;
	}
	

	public double getOpenPrice() {
		return openPrice;
	}


	public double getHighPrice() {
		return highPrice;
	}


	public double getLowPrice() {
		return lowPrice;
	}


	public double getClosePrice() {
		return closePrice;
	}


	public double getAdjustedClosePrice() {
		return adjustedClosePrice;
	}


	public long getVolume() {
		return volume;
	}


	public String toString() {
		return String.format("EndOfDayPrice{symbol=%s, date=%s, open=%f, high=%f, low=%f, close=%f, adj-close=%f, volume=%d}", 
							  symbol,
							  new Date(date),
							  openPrice,
							  highPrice,
							  lowPrice, 
							  closePrice,
							  adjustedClosePrice,
							  volume);
	}
		
	
	public void readExternal(DataInput in) throws IOException {
		symbol = ExternalizableHelper.readSafeUTF(in);
		date = ExternalizableHelper.readLong(in);
		openPrice = in.readDouble();
		highPrice = in.readDouble();
		lowPrice = in.readDouble();
		closePrice = in.readDouble();
		adjustedClosePrice = in.readDouble();
		volume = ExternalizableHelper.readLong(in);
	}

	
	public void writeExternal(DataOutput out) throws IOException {
		ExternalizableHelper.writeSafeUTF(out, symbol);
		ExternalizableHelper.writeLong(out, date);
		out.writeDouble(openPrice);
		out.writeDouble(highPrice);
		out.writeDouble(lowPrice);
		out.writeDouble(closePrice);
		out.writeDouble(adjustedClosePrice);		
		ExternalizableHelper.writeLong(out, volume);
	}
}
