import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Date;

import com.tangosol.io.ExternalizableLite;
import com.tangosol.util.ExternalizableHelper;


public class Message implements ExternalizableLite, Comparable<Message> {

	private static final long serialVersionUID = -4392783820323916479L;

	private String from;
	private long timeCreated;  //since EPOC
	private String text;
	
	public Message() {
		//for serializable
	}
	
	public Message(String from, String text) {
		this.timeCreated = System.currentTimeMillis();
		this.from = from;
		this.text = text;
	}

	public String getFrom() {
		return from;
	}
	
	public long getTimeCreated() {
		return timeCreated;
	}
	
	public Date getDate() {
		return new Date(timeCreated);
	}
	
	public String getText() {
		return text;
	}
	
	public int compareTo(Message other) {
		return (int)(this.timeCreated - other.timeCreated); 
	}

	public void readExternal(DataInput in) throws IOException {
		from = ExternalizableHelper.readSafeUTF(in);
		timeCreated = ExternalizableHelper.readLong(in);
		text = ExternalizableHelper.readSafeUTF(in);
	}
	
	public void writeExternal(DataOutput out) throws IOException {
		ExternalizableHelper.writeSafeUTF(out, from);
		ExternalizableHelper.writeLong(out, timeCreated);
		ExternalizableHelper.writeSafeUTF(out, text);
	}
}
