import java.io.Serializable;

import com.tangosol.net.cache.KeyAssociation;

public class Person implements Serializable {

	private static final long serialVersionUID = -1962017011816152404L;

	private long id;
	private String firstName;
	private String lastName;
	
	public Person() {
	}

	public Person(long id, String firstName, String lastName) {
		this.id = id;
		this.firstName = firstName;
		this.lastName = lastName;
	}

	public Key getKey() {
		return new Key(this);
	}	
	
	public long getId() {
		return id;
	}
	
	public String getFirstName() {
		return firstName;
	}
	
	public String getLastName() {
		return lastName;
	}

	public void sayHello() {
		System.out.printf("%s %s says 'hello'\n", firstName, lastName);
	}
	
	public String toString() {
		return String.format("Person{id=%d, firstName=%s, lastName=%s}", id, firstName, lastName);
	}
	
	public static class Key implements Serializable, KeyAssociation {

		private static final long serialVersionUID = 105575862751879799L;

		private long id;
		private String lastName;
		
		public Key() {
		}

		public Key(Person person) {
			this.id = person.getId();
			this.lastName = person.getLastName();
		}

		public Object getAssociatedKey() {
			return lastName;
		}
	
		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + (int) (id ^ (id >>> 32));
			result = prime * result
					+ ((lastName == null) ? 0 : lastName.hashCode());
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			final Key other = (Key) obj;
			if (id != other.id)
				return false;
			if (lastName == null) {
				if (other.lastName != null)
					return false;
			} else if (!lastName.equals(other.lastName))
				return false;
			return true;
		}

		@Override
		public String toString() {
			return String.format("Person.Key{id=%d, lastName=%s}", id, lastName);
		}
	}
}
